import tempfile
import zipfile as ziplib
from zipfile import ZIP_DEFLATED

from datetime import date
import os.path
from django.conf import settings
from django.http import HttpResponse
from reportserver.lib.export.formats.excelexport import export_xlsx_as_string


def get_arcname_by_templateid(templateid):
    return os.path.basename(templateid)


def get_template_by_templateid(templateid):
    return os.path.join(settings.STATIC_ROOT, "documents",
                        os.path.basename(templateid))


def get_rawdata_file_name(exportname):
    """Return the filename in the zip archive for the (raw) data.
    e.g. SIB_Teilnehmende.xlsx for sib and Teilnehmende."""
    program = settings.PROGRAM.upper()
    return "{}_{}.xlsx".format(program, exportname)


def get_ziparchive_file_name(exportname, simple_filenames):
    """Return the file name for the zip archive.
    E.g SIB_ESF-Auswertung_2017-11-15.zip"""
    program = settings.PROGRAM.upper()
    today = str(date.today())
    template = "{}_{}_Auswertungsvorlage_{}.zip"
    if simple_filenames:
        template = "{}_{}_{}.zip"
    return template.format(program, exportname, today)


def export_zip(rows, templateid, exportname, metadata, simple_filenames=False):
    """
    exports given rows together with template as zip
    :param rows:
    :param templateid:
    :return:
    """
    excel = export_xlsx_as_string(rows, metadata)

    arcname = get_arcname_by_templateid(templateid)
    template = get_template_by_templateid(templateid)

    result_filename = get_ziparchive_file_name(exportname, simple_filenames)

    with tempfile.TemporaryFile() as temp_file:
        with ziplib.ZipFile(temp_file, 'w', ZIP_DEFLATED) as zipfile:
            zipfile.writestr(get_rawdata_file_name(exportname), excel)
            zipfile.write(template, arcname)
        temp_file.seek(0)
        zip_stream = temp_file.read()

    response = HttpResponse(zip_stream, content_type="application/zip")
    response['Content-Disposition'] = \
        'attachment; filename="%s"' % result_filename

    return response
