# -*- coding: utf-8 -*-

from collections import defaultdict

import reportserver.lib.db.report_dal as reportdal
from reportserver.lib.export.formats.excelexport import export_xlsx
from reportserver.lib.report.esfreport import EsfReport


def group_by_beneficiary_id(rows):
    group_by = defaultdict(list)
    for r in rows:
        vorhaben = r["vorhaben"]
        group_by[vorhaben].append(r)
    return group_by


def generate_lines_from(reports_by_beneficiaryid, programname):
    columns = ["entries", "exits"] + EsfReport.indicators_for(programname)
    header = ["id", "total"]
    for i in columns:
        header.extend([i + "_gesamt", i + "_m", i + "_w"])
    lines = [header]
    beneficiary_ids = sorted(set(reports_by_beneficiaryid.keys()))
    for beneficiary_id in beneficiary_ids:
        report = reports_by_beneficiaryid[beneficiary_id]
        lines.append([beneficiary_id] + report.to_line())
    return lines


def create_esfexport_for(programname, filters, metadata):
    """
    Creates ESF-Export
    :param programname: 
    :param filters: 
    :return: 
    """
    rows = reportdal.retrieve_reportdata_for_export(filters, programname)
    reports_by_beneficiaryid = transform_to_esfreports(group_by_beneficiary_id(rows), programname)
    lines = generate_lines_from(reports_by_beneficiaryid, programname)
    return export_xlsx(lines, "Durchfuehrungsbericht", metadata)


def transform_to_esfreports(grouped, programname):
    for beneficiary, r in grouped.iteritems():
        grouped[beneficiary] = EsfReport(programname, r)
    return grouped
