import re

is_nuts1 = re.compile("[a-zA-Z0-9]{3}").match
is_regioncategory = re.compile("\d+").match
is_beneficiary = re.compile("[A-Z]{2,3}\.\d{4}\.\d{2}").match

def check_nuts1(nuts1, values):
    """
    Checks plausible nuts1
    1) Format has to be 3 alphanum chars
    2) It has to be a code known to DB
    :param nuts1:
    :param values:
    :return:
    """
    if not nuts1:
        return
    if isinstance(nuts1, list):
        if not all([is_nuts1(n) for n in nuts1]):
            raise ValueError
        if set(nuts1) - set(values):
            raise ValueError
    else:
        if not is_nuts1(nuts1):
            raise ValueError
        if nuts1 not in values:
            raise ValueError

def check_beneficiary(beneficiary, values):
    """
    Checks plausible beneficiary
    1) Format has to be 3 alphanum chars
    2) It has to be a code known to DB
    :param beneficiary:
    :param values:
    :return:
    """
    if not beneficiary:
        return
    if isinstance(beneficiary, list):
        if not all([is_beneficiary(b) for b in beneficiary]):
            raise ValueError
        if set(beneficiary) - set(values):
            raise ValueError
    else:
        if not is_beneficiary(beneficiary):
            raise ValueError
        if beneficiary not in values:
            raise ValueError


def check_regioncategory(regioncategory, values):
    """
    Checks plausible regioncategory
    1) Format has to be 3 alphanum chars
    2) It has to be a code known to DB
    :param regioncategory:
    :param values:
    :return:
    """
    if not regioncategory:
        return
    if isinstance(regioncategory, list):
        if not all([is_regioncategory(r) for r in regioncategory]):
            raise ValueError
        if set([int(r) for r in regioncategory]) - set(values):
            raise ValueError
    else:
        if not is_regioncategory(regioncategory):
            raise ValueError
        if int(regioncategory) not in values:
            raise ValueError

def check_gender(gender):
    if not gender:
        return
    if isinstance(gender, list):
        if not all([g in ("0", "1") for g in gender]):
            raise ValueError
    else:
        if not gender in ("0", "1"):
            raise ValueError


def check_filter_type(filter_type):
    if filter_type not in ("1", "2", "3", "4", "5"):
        raise ValueError
